@@ -6,6 +6,8 @@ from .funcs import *
 from .seqs import *
 from .strings import *
 from .flow import ignore, silent, retry, fallback # partially experimental
+from .objects import cached_property
+from .namespaces import namespace
 # from debug import * # fully experimental
 
 
