@@ -1,8 +1,9 @@
 from datetime import datetime, timedelta
 from functools import wraps
+import inspect
 
 
-__all__ = ['memoize', 'cache']
+__all__ = ['memoize', 'make_lookuper', 'cache']
 
 
 class SkipMemoization(Exception):
@@ -25,17 +26,26 @@ def memoize(func):
 memoize.skip = SkipMemoization
 
 
-def lookup(func):
-    memory = {}
+def make_lookuper(func):
+    spec = inspect.getargspec(func)
+    assert not spec.keywords,  \
+           'Lookup table building function should not have keyword arguments'
 
-    @wraps(func)
-    def wrapper(arg):
-        if not memory:
-            memory[object()] = None # prevent continuos memory refilling
-            memory.update(func())
-        return memory.get(arg)
-    return wrapper
-memoize.lookup = lookup
+    if spec.args or spec.varargs:
+        @memoize
+        def wrapper(*args):
+            return make_lookuper(lambda: func(*args))
+    else:
+        memory = {}
+
+        @wraps(func)
+        def wrapper(arg):
+            if not memory:
+                memory[object()] = None # prevent continuos memory refilling
+                memory.update(func())
+            return memory.get(arg)
+
+    return wraps(func)(wrapper)
 
 
 def cache(timeout):
