@@ -8,14 +8,30 @@ __all__ = ['ignore', 'silent', 'fallback', 'limit_error_rate', 'ErrorRateExceede
 
 
 @decorator
-def ignore(call, errors):
+def ignore(call, errors, default=None):
     try:
         return call()
     except errors:
-        return None
+        return default
 
 silent = ignore(Exception) # Ignore all real exceptions
 
+
+# NOTE: is it usefull enough?
+# EMPTY = object()
+#
+# @decorator
+# def handle(call, exceptions=EMPTY, default=EMPTY):
+#     try:
+#         return call()
+#     except BaseException as e:
+#         result = exceptions.get(e.__class__, default)
+#         if result is DONT_HANDLE:
+#             raise
+#         else:
+#             return result
+
+
 @decorator
 def retry(call, tries, errors=Exception):
     for attempt in range(tries):
