@@ -8,10 +8,10 @@ __all__ = ['count', 'cycle', 'repeat', 'repeatedly', 'iterate',
            'take', 'drop', 'first', 'second', 'rest', 'ilen',
            'ireductions', 'reductions',
            'imap', 'ifilter', 'remove', 'iremove', 'keep', 'ikeep',
-           'concat', 'iconcat', 'cat', 'icat', 'mapcat', 'imapcat',
+           'concat', 'iconcat', 'chain', 'cat', 'icat', 'mapcat', 'imapcat',
            'izip', 'interleave', 'interpose', 'distinct',
            'dropwhile', 'takewhile', 'split', 'split_at', 'split_by',
-           'group_by', 'partition', 'chunks']
+           'group_by', 'partition', 'chunks', 'with_prev']
 
 
 from itertools import count, cycle, repeat
@@ -45,23 +45,6 @@ def ilen(seq):
     return sum(1 for _ in seq)
 
 
-EMPTY = object()
-
-def ireductions(f, seq, acc=EMPTY):
-    it = iter(seq)
-    if acc is EMPTY:
-        last = next(it)
-        yield last
-    else:
-        last = acc
-    for x in it:
-        last = f(last, x)
-        yield last
-
-def reductions(f, seq, acc=EMPTY):
-    return list(ireductions(f, seq, acc))
-
-
 # TODO: tree-seq equivalent
 
 def remove(pred, seq):
@@ -150,3 +133,23 @@ def chunks(n, step, seq=None):
         return chunks(n, n, step)
     return [seq[i:i+n] for i in xrange(0, len(seq), step)]
 
+def with_prev(seq):
+    a, b = tee(seq)
+    return izip(a, chain([None], b))
+
+
+EMPTY = object()
+
+def ireductions(f, seq, acc=EMPTY):
+    it = iter(seq)
+    if acc is EMPTY:
+        last = next(it)
+        yield last
+    else:
+        last = acc
+    for x in it:
+        last = f(last, x)
+        yield last
+
+def reductions(f, seq, acc=EMPTY):
+    return list(ireductions(f, seq, acc))
